import {
  UserLayout,
  BasicLayout,
  RouteView,
  PageView
} from '@/layouts'

export const asyncRouterMap = [{
  path: '/',
  name: 'index',
  component: BasicLayout,
  meta: {
    title: '首页'
  },
  redirect: '/home',
  children: [{
    path: '/home',
    name: 'home',
    redirect: '/home',
    component: PageView,
    meta: {
      title: '首页',
      icon: 'home'
    },
    hideChildrenInMenu: true,
    children: [{
      path: '/home',
      name: 'home',
      component: () => import(/* webpackChunkName: "home" */ '@/views/Home'),
      meta: {
        title: '首页',
        icon: 'home',
        hidden: true
      }
    },
    {
      path: '/changePwd',
      name: 'changePwd',
      component: () => import(/* webpackChunkName: "home" */ '@/views/user/ChangePwd'),
      meta: {
        title: '修改密码',
        icon: 'home',
        hidden: true
      }
    }
    ]
  },
  {
    path: '/SetmealSales',
    redirect: '/SetmealSales/VerificationRecords',
    name: 'SetmealSales',
    component: PageView,
    meta: {
      title: '套餐销售',
      icon: 'snippets',
      permission: 'M_bundel_saller'
    },
    children: [
      {
        path: '/SetmealSales/BuySetmeal',
        name: 'BuySetmeal',
        component: () => import('@/views/SetmealSales/BuySetmeal.vue'),
        meta: {
          title: '购买套餐',
          icon: 'file-text',
          permission: 'M_buy_bundel'
        }
      },
      {
        path: '/SetmealSales/PurchasedSetmeal',
        name: 'PurchasedSetmeal',
        component: () => import('@/views/SetmealSales/PurchasedSetmeal.vue'),
        meta: {
          title: '已购套餐',
          icon: 'file-text',
          permission: 'M_bundel_buyRecord'
        }
      },
      {
        path: '/SetmealSales/SetmealAttr',
        name: 'SetmealAttr',
        component: () => import('@/views/SetmealSales/SetmealAttr.vue'),
        meta: {
          title: '套餐属性',
          icon: 'file-text',
          permission: 'M_buy_attr'
        }
      }
    ]
  },
  // 服务
  {
    path: '/Service',
    redirect: '/Service/PurchasedService',
    component: PageView,
    meta: {
      title: '服务',
      icon: 'profile',
      permission: 'M_Service'
    },
    children: [
      {
        path: '/Service/PurchasedService',
        redirect: '/Service/PurchasedService/list',
        name: 'PurchasedService',
        component: RouteView,
        meta: {
          title: '已购服务',
          icon: 'profile',
          permission: 'M_Service_list'
        },
        hideChildrenInMenu: true,
        children: [
          {
            path: '/Service/PurchasedService/list',
            name: 'PurchasedServiceList',
            component: () => import(/* webpackChunkName: "order" */ '@/views/Service/PurchasedServiceList.vue'),
            meta: {
              title: '服务列表',
              icon: 'shopping',
              hidden: true
            }
          },
          {
            path: '/Service/PurchasedService/detail/:id',
            name: 'PurchasedServiceDetail',
            component: () => import(/* webpackChunkName: "order" */ '@/views/Service/PurchasedServiceDetail.vue'),
            meta: {
              title: '服务详情',
              icon: 'profile',
              hidden: true
            }
          }
        ]
      }
    ]
  },
  {
    path: '/FinancialManagement',
    name: 'FinancialManagement',
    redirect: '/FinancialManagement/VerificationRecords',
    component: PageView,
    meta: { title: '财务管理', icon: 'account-book', permission: 'M_cwgn' },
    children: [
      {
        path: '/FinancialManagement/VerificationRecords',
        name: 'VerificationRecords',
        component: () => import('@/views/SetmealSales/VerificationRecords.vue'),
        meta: {
          title: '核销记录',
          icon: 'file-text',
          permission: 'M_hxjl_list'
        }
      },
      {
        path: '/FinancialManagement/PaySettlementRecords',
        name: 'PaySettlementRecords',
        component: () => import(/* webpackChunkName: "writeOff" */ '@/views/FinancialManagement/PaySettlementRecords.vue'),
        meta: { title: '应付结算记录-套餐', icon: 'form', permission: 'M_yfjs_js_list' }
      }
    ]
  },
  {
    path: '/auth',
    redirect: '/auth/userList',
    component: PageView,
    meta: {
      title: '运营平台权限管理',
      icon: 'apartment',
      permission: 'M_power_auth'
    },
    children: [
      {
        path: '/auth/userList',
        name: 'powerUserList',
        component: () => import(/* webpackChunkName: "auth" */ '@/views/power/user/userList.vue'),
        meta: {
          title: '用户管理',
          icon: 'user',
          permission: 'M_power_user_list'
        }
      },
      {
        path: '/auth/roleList',
        name: 'powerRoleList',
        component: () => import(/* webpackChunkName: "auth" */ '@/views/power/role/roleList.vue'),
        meta: {
          title: '角色管理',
          icon: 'solution',
          permission: 'M_power_role_list'
        }
      }
    ]
  }
  ]
},
{
  path: '*',
  redirect: '/404',
  hidden: true
}
]

/**
 * 基础路由
 * @type { *[] }
 */
export const constantRouterMap = [{
  path: '/user',
  component: UserLayout,
  redirect: '/user/login',
  hidden: true,
  children: [{
    path: 'login',
    name: 'login',
    component: () => import(/* webpackChunkName: "user" */ '@/views/user/Login')
  },
  {
    path: 'register',
    name: 'register',
    component: () => import(/* webpackChunkName: "user" */ '@/views/user/Register')
  },
  {
    path: 'register-result',
    name: 'registerResult',
    component: () => import(/* webpackChunkName: "user" */ '@/views/user/RegisterResult')
  },
  {
    path: 'recover',
    name: 'recover',
    component: undefined
  }
  ]
},
{
  path: '/404',
  component: () => import(/* webpackChunkName: "fail" */ '@/views/exception/404')
}

]
